ams.core.service.VarReduction
=============================

.. currentmodule:: ams.core.service

.. autoclass:: VarReduction

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~VarReduction.assign_memory
       
       
          ~VarReduction.evaluate
       
       
          ~VarReduction.get_names
       
       
          ~VarReduction.parse
       
       
          ~VarReduction.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~VarReduction.class_name
      ~VarReduction.n
      ~VarReduction.shape
      ~VarReduction.size
      ~VarReduction.v
      ~VarReduction.v0
      ~VarReduction.v1
   
   